#!/bin/sh

setWASHome()
{
    if [ "${REPLACE_WAS_HOME:=}" != "" ] && [ -d ${REPLACE_WAS_HOME} ]
    then
        WAS_HOME=${REPLACE_WAS_HOME}
    else
        CUR_DIR=`pwd`
        WAS_DIR=`dirname ${0}`/../
        cd "${WAS_DIR}"
        WAS_HOME=`pwd`
        cd "${CUR_DIR}"
    fi
}
setWASHome

JAVA_HOME="$WAS_HOME/java"
PLATFORM=`/bin/uname`

FSDB_PATH="$WAS_HOME/properties/fsdb"
if [ "$PLATFORM" != "OS/390" ]; then 
  DEFAULT_PROFILE_REGISTRY_LOC="$WAS_HOME/properties/profileRegistry.xml"
  if [ ! -f ${DEFAULT_PROFILE_REGISTRY_LOC} ]; then
    FSDB_PATH=`$JAVA_HOME/jre/bin/java -classpath $WAS_HOME/lib/setup.jar com.ibm.ws.setup.SetupFsdbPath $WAS_HOME 2>/dev/null`
  fi
fi

DEFAULT_PROFILE_SCRIPT="$FSDB_PATH"/_was_profile_default/default.sh

ITP_LOC="$WAS_HOME"/deploytool/itp
PROFILE_REGISTRY_LOC="$FSDB_PATH"

ARCH=`/bin/uname -m`

CONFIG_ROOT="$WAS_HOME"/config
SERVERSAS=-Dcom.ibm.CORBA.ConfigURL=file:"$WAS_HOME"/properties/sas.server.props
CLIENT_CONNECTOR_INSTALL_ROOT="$WAS_HOME"/installedConnectors
WAS_LOGGING="-Djava.util.logging.manager=com.ibm.ws.bootstrap.WsLogManager -Djava.util.logging.configureByServer=true"

QUALIFYNAMES=-qualifyHomeName
PATH="$JAVA_HOME"/ibm_bin:"$JAVA_HOME"/bin/:"$JAVA_HOME"/jre/bin:$PATH
WAS_EXT_DIRS="$JAVA_HOME"/lib:"$WAS_HOME"/classes:"$WAS_HOME"/lib:"$WAS_HOME"/installedChannels:"$WAS_HOME"/lib/ext:"$WAS_HOME"/web/help:"$ITP_LOC"/plugins/com.ibm.etools.ejbdeploy/runtime
WAS_CLASSPATH="$WAS_HOME"/properties:"$WAS_HOME"/lib/startup.jar:"$WAS_HOME"/lib/bootstrap.jar:"$JAVA_HOME"/lib/tools.jar:"$WAS_HOME"/lib/lmproxy.jar:"$WAS_HOME"/lib/urlprotocols.jar

DERBY_HOME="$WAS_HOME"/derby

case $PLATFORM in

  AIX)

    WAS_LIBPATH="$WAS_HOME"/bin
    WAS_EXT_DIRS="$WAS_EXT_DIRS"
    NLSPATH=/usr/lib/nls/msg/%L/%N:/usr/lib/nls/msg/en_US/%N:${NLSPATH:=}
#    WAS_BOOTCLASSPATH=
    ;;

  Linux)

    WAS_LIBPATH="$WAS_HOME"/bin
    WAS_EXT_DIRS="$WAS_EXT_DIRS"
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
    JAVA_HIGH_ZIPFDS=200
#    WAS_BOOTCLASSPATH=
    ;;

  SunOS)

    if [ "$LANG" = "" ]
    then
       LANG=C
       export LANG
    fi
    WAS_LIBPATH="$WAS_HOME"/bin
    WAS_EXT_DIRS="$WAS_EXT_DIRS"
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
#    WAS_BOOTCLASSPATH=
    if [ $ARCH = "i86pc" ]
    then
      JVM_EXTRA_CMD_ARGS=-d64
    else
       file "$WAS_HOME"/bin/libNativeFile.so | grep "ELF 64" > /dev/null
       if [ $? = 0 -a -d $JAVA_HOME/jre/bin/sparcv9 ];then
          JVM_EXTRA_CMD_ARGS=-d64
       fi
    fi

    ;;

  HP-UX)

    WAS_LIBPATH="$WAS_HOME"/bin
    WAS_EXT_DIRS="$WAS_EXT_DIRS"
    NLSPATH=/usr/lib/nls/msg/%L/%N:${NLSPATH:=}
#    WAS_BOOTCLASSPATH=
    if [ "$ARCH" = "ia64" ]
    then
      JVM_EXTRA_CMD_ARGS="-d64 -Djava.net.preferIPv4Stack=false"
    else
      JVM_EXTRA_CMD_ARGS=-Djava.net.preferIPv4Stack=false
    fi;;
    
  OS/390)

    LIBPATH=$LIBPATH:"$WAS_HOME"/lib
    WAS_LIBPATH="$WAS_HOME"/bin
    WAS_EXT_DIRS="$WAS_EXT_DIRS"
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
    WAS_CLASSPATH="$WAS_CLASSPATH":"$WAS_HOME"/lib/bootstrapws390.jar
#    WAS_BOOTCLASSPATH=
    ;;

  *)

    LIBPATH=$LIBPATH:"$WAS_HOME"/lib
    WAS_LIBPATH="$WAS_HOME"/bin
    WAS_EXT_DIRS="$WAS_EXT_DIRS"
    NLSPATH=/usr/lib/locale/%L/LC_MESSAGES/%N:${NLSPATH:=}
#    WAS_BOOTCLASSPATH=
    ;;

esac

OSGI_INSTALL="-Dosgi.install.area=$WAS_HOME"
OSGI_CFG="-Dosgi.configuration.area=$WAS_HOME/configuration"

export PATH WAS_HOME WAS_CELL WAS_NODE JAVA_HOME ITP_LOC SERVERSAS CLIENT_CONNECTOR_INSTALL_ROOT WAS_LOGGING QUALIFYNAMES WAS_EXT_DIRS WAS_CLASSPATH CONFIG_ROOT NLSPATH JAVA_HIGH_ZIPFDS WAS_LIBPATH JVM_EXTRA_CMD_ARGS LIBPATH OSGI_INSTALL OSGI_CFG

#Platform specific args...
PLATFORM=`/bin/uname`
case $PLATFORM in
  AIX)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  Linux)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  SunOS)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  HP-UX)
    CONSOLE_ENCODING=-Dws.output.encoding=console;;
  OS/390)
    EXTRA_D_ARG=-Dfile.encoding=ISO8859-1
    EXTRA_X_ARG=-Xnoargsconversion ;;
esac

# Set java options for performance
PLATFORM=`/bin/uname`
case $PLATFORM in
  AIX)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -Xquickstart" ;;
  Linux)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -Xj9 -Xquickstart" ;;
  SunOS)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -XX:PermSize=40m -XX:MaxPermSize=128m -XX:+UnlockDiagnosticVMOptions -XX:+UnsyncloadClass" ;;
  HP-UX)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m -XX:PermSize=40m -XX:MaxPermSize=128m -XX:+UnlockDiagnosticVMOptions -XX:+UnsyncloadClass" ;;
  OS/390)
      PERF_JVM_OPTIONS="-Xms512m -Xmx768m" ;;
esac 

"$JAVA_HOME/bin/java" \
  "$OSGI_INSTALL" "$OSGI_CFG" \
  $EXTRA_X_ARG \
  $CONSOLE_ENCODING \
  -DKeepProfileName=true \
  -Dcom.ibm.websphere.migration.serverRoot="$WAS_HOME" \
  -Dcom.ibm.jsse2.checkRevocation=false \
  -Dcom.ibm.security.enableCRLDP=false \
  -Dcom.ibm.ws.migration.currentProfileLogLocation="$USER_INSTALL_ROOT" \
  -Dcom.ibm.SSL.ConfigURL="file:$USER_INSTALL_ROOT/properties/ssl.client.props" \
  -Dws.ext.dirs="$WAS_EXT_DIRS" \
  -Duser.install.root="$USER_INSTALL_ROOT" \
  -Dwas.install.root="$WAS_HOME" \
  $PERF_JVM_OPTIONS \
  ${JAASSOAP:+"$JAASSOAP"} \
  $WAS_LOGGING \
  $EXTRA_D_ARG \
  $JVM_EXTRA_CMD_ARGS \
  -classpath "$WAS_CLASSPATH":"$WAS_HOME"/properties:"$WAS_HOME"/derby/lib/derby.jar:"$WAS_HOME"/derby/migration/migratetoderby.jar com.ibm.wsspi.bootstrap.WSPreLauncher \
  -nosplash  -application com.ibm.ws.bootstrap.WSLauncher com.ibm.wbicommon.migration.BPMGenerateUpgradeSchemaScripts "$@"


